@@ -29,9 +29,19 @@
 #include "dh-book.h"
 #include "dh-util.h"
 
-typedef struct {
-        DhBookManager *book_manager;
+/**
+ * SECTION:dh-keyword-model
+ * @Title: DhKeywordModel
+ * @Short_description: A custom #GtkTreeModel implementation for searching a
+ * keyword
+ *
+ * #DhKeywordModel is a custom #GtkTreeModel implementation (as a list, not a
+ * tree) for searching a keyword.
+ *
+ * The dh_keyword_model_filter() function is used to set the search criteria.
+ */
 
+typedef struct {
         gchar *current_book_id;
 
         /* List of DhLink* */
@@ -73,16 +83,6 @@ G_DEFINE_TYPE_WITH_CODE (DhKeywordModel, dh_keyword_model, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
                                                 dh_keyword_model_tree_model_init));
 
-static void
-dh_keyword_model_dispose (GObject *object)
-{
-        DhKeywordModelPrivate *priv = dh_keyword_model_get_instance_private (DH_KEYWORD_MODEL (object));
-
-        g_clear_object (&priv->book_manager);
-
-        G_OBJECT_CLASS (dh_keyword_model_parent_class)->dispose (object);
-}
-
 static void
 dh_keyword_model_finalize (GObject *object)
 {
@@ -99,7 +99,6 @@ dh_keyword_model_class_init (DhKeywordModelClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);;
 
-        object_class->dispose = dh_keyword_model_dispose;
         object_class->finalize = dh_keyword_model_finalize;
 }
 
@@ -358,9 +357,7 @@ dh_keyword_model_tree_model_init (GtkTreeModelIface *iface)
 /**
  * dh_keyword_model_new:
  *
- * Create a new #DhKeywordModel object.
- *
- * Returns: a new #DhKeywordModel object
+ * Returns: a new #DhKeywordModel object.
  */
 DhKeywordModel *
 dh_keyword_model_new (void)
@@ -368,27 +365,6 @@ dh_keyword_model_new (void)
         return g_object_new (DH_TYPE_KEYWORD_MODEL, NULL);
 }
 
-/**
- * dh_keyword_model_set_words:
- * @model: a #DhKeywordModel object
- * @book_manager: a #DhBookManager to analyze
- *
- * Set the #DhBookManager object on which words are analyzed.
- */
-void
-dh_keyword_model_set_words (DhKeywordModel *model,
-                            DhBookManager  *book_manager)
-{
-        DhKeywordModelPrivate *priv;
-
-        g_return_if_fail (DH_IS_KEYWORD_MODEL (model));
-        g_return_if_fail (DH_IS_BOOK_MANAGER (book_manager));
-
-        priv = dh_keyword_model_get_instance_private (model);
-
-        priv->book_manager = g_object_ref (book_manager);
-}
-
 /* For each keyword, creates a DhKeywordGlobPattern with GPatternSpec's
  * allocated if there are any special glob characters ('*', '?') in the keyword.
  */
@@ -598,15 +574,14 @@ keyword_model_search_books (DhKeywordModel  *model,
                             guint            max_hits,
                             DhLink         **exact_link)
 {
-        DhKeywordModelPrivate *priv;
+        DhBookManager *book_manager;
         GQueue *ret;
         GList *l;
 
-        priv = dh_keyword_model_get_instance_private (model);
-
+        book_manager = dh_book_manager_get_singleton ();
         ret = g_queue_new ();
 
-        for (l = dh_book_manager_get_books (priv->book_manager);
+        for (l = dh_book_manager_get_books (book_manager);
              l != NULL && ret->length < max_hits;
              l = l->next) {
                 DhBook *book;
@@ -981,15 +956,16 @@ set_keywords_list (DhKeywordModel *model,
 
 /**
  * dh_keyword_model_filter:
- * @model: a #DhKeywordModel object
- * @search_string: a search query
- * @book_id: (nullable): the id of a specific book or %NULL for all books
- * @language: (nullable): the name of a language or %NULL for all languages
+ * @model: a #DhKeywordModel.
+ * @search_string: a search query.
+ * @book_id: (nullable): the ID of the book currently selected, or %NULL.
+ * @language: (nullable):
  *
- * Find the book matching the given criteria.
+ * Searches in the #DhBookManager the list of #DhLink's that correspond to
+ * @search_string, and fills the @model with that list.
  *
- * Returns: (nullable) (transfer none): the corresponding #DhLink or %NULL if
- * no link corresponding to the criteria is found
+ * Returns: (nullable) (transfer none): the #DhLink that matches exactly
+ * @search_string, or %NULL if there is no such #DhLink.
  */
 DhLink *
 dh_keyword_model_filter (DhKeywordModel *model,
